summaryrefslogtreecommitdiffstats
path: root/Source/cmCableDefineSetCommand.h
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableDefineSetCommand.h
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableDefineSetCommand.h')
-rw-r--r--Source/cmCableDefineSetCommand.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/Source/cmCableDefineSetCommand.h b/Source/cmCableDefineSetCommand.h
index 3d598b1..8d002cf 100644
--- a/Source/cmCableDefineSetCommand.h
+++ b/Source/cmCableDefineSetCommand.h
@@ -13,20 +13,20 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#ifndef cmCabilDefineSetCommand_h
-#define cmCabilDefineSetCommand_h
+#ifndef cmCableDefineSetCommand_h
+#define cmCableDefineSetCommand_h
#include "cmStandardIncludes.h"
#include "cmCabilCommand.h"
/** \class cmCabilDefineSetCommand
* \brief Define a command that adds a CABIL Set definition.
*
* cmCabilDefineSetCommand is used to define a named CABIL Set.
* The set can be referenced in other CABIL command arguments
* with a '$' followed by the set name.
*/
-class cmCabilDefineSetCommand : public cmCabilCommand
+class cmCableDefineSetCommand : public cmCableCommand
{
public:
/**
@@ -34,7 +34,7 @@ public:
*/
virtual cmCommand* Clone()
{
- return new cmCabilDefineSetCommand;
+ return new cmCableDefineSetCommand;
}
/**
@@ -53,14 +53,14 @@ public:
/**
* The name of the command as specified in CMakeList.txt.
*/
- virtual const char* GetName() { return "CABIL_DEFINE_SET";}
+ virtual const char* GetName() { return "CABLE_DEFINE_SET";}
/**
* Succinct documentation.
*/
virtual const char* GetTerseDocumentation()
{
- return "Define a CABIL Set.";
+ return "Define a CABLE Set.";
}
/**
@@ -69,15 +69,15 @@ public:
virtual const char* GetFullDocumentation()
{
return
- "CABIL_DEFINE_SET(name_of_set member1 member2 ...)\n"
- "Generates a Set definition in the CABIL configuration. Tags are\n"
- "automatically generated. The sets are referenced in other CABIL\n"
+ "CABLE_DEFINE_SET(name_of_set member1 member2 ...)\n"
+ "Generates a Set definition in the CABLE configuration. Tags are\n"
+ "automatically generated. The sets are referenced in other CABLE\n"
"commands by a '$' immediately followed by the set name (ex. $SetName).";
}
virtual void WriteConfiguration(std::ostream&) const;
- cmTypeMacro(cmCabilDefineSetCommand, cmCabilCommand);
+ cmTypeMacro(cmCableDefineSetCommand, cmCableCommand);
private:
std::string GenerateTag(const std::string&) const;
@@ -13,20 +13,20 @@
#include "cmStandardIncludes.h"
-#include "cmCabilCommand.h"
+#include "cmCableCommand.h"
-/** \class cmCabilDefineSetCommand
- * \brief Define a command that adds a CABIL Set definition.
+/** \class cmCableDefineSetCommand
+ * \brief Define a command that adds a CABLE Set definition.
*
@@ -13,20 +13,20 @@
*
- * cmCabilDefineSetCommand is used to define a named CABIL Set.
- * The set can be referenced in other CABIL command arguments
+ * cmCableDefineSetCommand is used to define a named CABLE Set.
+ * The set can be referenced in other CABLE command arguments
* with a '$' followed by the set name.
*/